Class: Yeah::Sound Abstract

Inherits:
Asset
  • Object
show all
Defined in:
lib/yeah/_platform/sound.rb

Overview

This class is abstract.

Provided by a Platform.

A Sound is an audio asset, which can be used to provide music and sound effects for a game.

Examples:

Playing a sound

Sound['sounds/neigh.wav'].play

Instance Attribute Summary

Attributes inherited from Asset

#path

Method Summary

Methods inherited from Asset

#[], #initialize

Constructor Details

This class inherits a constructor from Yeah::Asset