Class: Yeah::Sound Abstract
Overview
This class is abstract.
Provided by a Platform.
A Sound is an audio asset, which can be used to provide music and sound effects for a game.
Instance Attribute Summary
Attributes inherited from Asset
Method Summary
Methods inherited from Asset
Constructor Details
This class inherits a constructor from Yeah::Asset